@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: machine.h,v 1.31 2001/07/18 14:01:49 abe Exp $
+ * $Id: machine.h,v 1.41 2006/03/27 23:09:21 abe Exp $
  */
 
 
@@ -69,9 +69,9 @@
 
 #include <sys/types.h>
 
-#   if	AIXA>=1
+#   if	AIXA>0
 #include <sys/resource.h>
-#   endif	/* AIXA>=1 */
+#   endif	/* AIXA>0 */
 
 # if	defined(__GNUC__)
 typedef	long long	aligned_off64_t __attribute__ ((aligned (8)));
@@ -94,9 +94,17 @@ typedef	long long	aligned_offset_t  __attribute__ ((aligned (8)));
  * can be used to obtain a CLIENT handle in lieu of clnttcp_create().
  */
 
-#if	AIXV>=4200
+# if	AIXV>=4200
 #define	CAN_USE_CLNT_CREATE	1
-#endif	/* AIXV>=4200 */
+# endif	/* AIXV>=4200 */
+
+
+/*
+ * DEVDEV_PATH defines the path to the directory that contains device
+ * nodes.
+ */
+
+#define	DEVDEV_PATH	"/dev"
 
 
 /*
@@ -186,10 +194,19 @@ typedef	long long	aligned_offset_t  __attribute__ ((aligned (8)));
  * FSV_DEFAULT defines the default set of file structure values to list.
  * It defaults to zero (0), but may be made up of a combination of the
  * FSV_* symbols from lsof.h.
+ *
+ *   HASNOFSADDR  -- has no file structure address
+ *   HASNOFSFLAGS -- has no file structure flags
+ *   HASNOFSCOUNT -- has no file structure count
+ *   HASNOFSNADDR -- has no file structure node address
  */
 
 #define	HASFSTRUCT	1
 /* #define	FSV_DEFAULT	FSV_? | FSV_? | FSV_? */
+/* #define	HASNOFSADDR	1	has no file structure address */
+/* #define	HASNOFSFLAGS	1	has no file structure flags */
+/* #define	HASNOFSCOUNT	1	has no file structure count */
+/* #define	HASNOFSNADDR	1	has no file structure node address */
 
 
 /*
@@ -243,14 +260,40 @@ typedef	long long	aligned_offset_t  __attribute__ ((aligned (8)));
  * in struct lfile.  The HASLFILEADD definition is a macro that defines
  * them.  If any of the additional elements need to be preset in the
  * alloc_lfile() function of proc.c, the SETLFILEADD macro may be defined
- * to do that.  The HASXOPT definition may be used to select the conditions
- * under which private lfile elements are used.
+ * to do that.
+ *
+ * If any additional elements need to be cleared in alloc_lfile() or in the
+ * free_proc() function of proc.c, the CLRLFILEADD macro may be defined to
+ * do that.  Note that CLRLFILEADD takes one argument, the pointer to the
+ * lfile struct.  The CLRLFILEADD macro is expected to expand to statements
+ * that are complete -- i.e., have terminating semi-colons -- so the macro is
+ * called without a terminating semicolon by proc.c.
+ *
+ * The HASXOPT definition may be used to select the conditions under which
+ * private lfile elements are used.
  */
 
 /* #define HASLFILEADD int ... */
+/* #define CLRLFILEADD(lf)	(lf)->... = (type)NULL;	*/
 /* #define SETLFILEADD Lf->... */
 
 
+/*
+ * HASMNTSTAT indicates the dialect supports the mount stat(2) result option
+ * in its l_vfs and mounts structures.
+ */
+
+/* #define	HASMNTSTAT	1	*/
+
+
+/*
+ * HASMNTSUP is defined for those dialects that support the mount supplement
+ * option.
+ */
+
+/* #define	HASMNTSUP	1	*/
+
+
 /*
  * HASMOPT is defined for those dialects that support the reading of
  * kernel memory from an alternate file.
@@ -264,16 +307,12 @@ typedef	long long	aligned_offset_t  __attribute__ ((aligned (8)));
  * that lsof can search.  A value of 1 directs printname() to prefix the
  * cache value with the file system directory name; 2, avoid the prefix.
  *
- * HASNCAPID is defined for those dialects with a searchable kernel name
- * cache whose cache and vnodes are linked by a capability ID.
- *
  * NCACHELDPFX is a set of C commands to execute before calling ncache_load().
  *
  * NCACHELDSFX is a set of C commands to execute after calling ncache_load().
  */
 
 /* #define	HASNCACHE	1	*/
-/* #define	HASNCAPID	1	*/
 /* #define	NCACHELDPFX	??? */
 /* #define	NCACHELDSFX	??? */
 
@@ -395,15 +434,15 @@ typedef	long long	aligned_offset_t  __attribute__ ((aligned (8)));
  * by inode number.
  */
 
-#if	AIXA<1
+# if	AIXA<1
 /* #define	HASPROCFS	"proc?" */
 /* #define	HASFSTYPE	1 */
 /* #define	HASPINODEN	1 */
-#else	/* AIXA>=1 */
+# else	/* AIXA>=1 */
 #define	HASPROCFS	"proc"
 #define	HASFSTYPE	2
 #define	HASPINODEN	1
-#endif	/* AIXA<1 */
+# endif	/* AIXA<1 */
 
 
 /*
@@ -426,13 +465,33 @@ typedef	long long	aligned_offset_t  __attribute__ ((aligned (8)));
 /* #define	HASSECURITY	1	*/
 
 
+/*
+ * If HASSECURITY is defined, define HASNOSOCKSECURITY to allow users
+ * restricted by HASSECURITY to list any open socket files, provide their
+ * listing is selected by the "-i" option.
+ */
+
+/* #define	HASNOSOCKSECURITY	1	*/
+
+
 /*
  * HASSETLOCALE is defined for those dialects that have <locale.h> and
  * setlocale().
+ *
+ * If the dialect also has wide character support for language locales,
+ * HASWIDECHAR activates lsof's wide character support and WIDECHARINCL
+ * defines the header file (if any) that must be #include'd to use the
+ * mblen() and mbtowc() functions.
  */
 
 #define	HASSETLOCALE	1
 
+# if	AIXV>=4320
+#define	HASWIDECHAR	1
+# endif	/* AIXV>=4320 */
+
+/* #define	WIDECHARINCL	<wchar.h>	*/
+
 
 /*
  * HASSNODE is defined for those dialects that have snodes.
@@ -441,6 +500,17 @@ typedef	long long	aligned_offset_t  __attribute__ ((aligned (8)));
 /* #define	HASSNODE	1 */
 
 
+/*
+ * HASSOOPT, HASSOSTATE and HASTCPOPT define the availability of information
+ * on socket options (SO_* symbols), socket states (SS_* symbols) and TCP
+ * options.
+ */
+
+#define	HASSOOPT	1	/* has socket option information */
+#define	HASSOSTATE	1	/* has socket state information */
+#define	HASTCPOPT	1	/* has TCP options or flags */
+
+
 /*
  * Define HASSPECDEVD to be the name of a function that handles the results
  * of a successful stat(2) of a file name argument.
@@ -519,6 +589,22 @@ typedef	long long	aligned_offset_t  __attribute__ ((aligned (8)));
 #define	HASXOPT_VALUE	0
 
 
+/*
+ * INODETYPE and INODEPSPEC define the internal node number type and its
+ * printf specification modifier.  These need not be defined and lsof.h
+ * can be allowed to define defaults.
+ *
+ * These are defined here, because they must be used in dlsof.h.
+ */
+
+# if	AIXV>=4200
+#define	INODETYPE	unsigned long long
+					/* inode number internal storage type */
+#define	INODEPSPEC	"ll"		/* INODETYPE printf specification
+					 * modifier */
+# endif	/* AIXV>=4200 */
+
+
 /*
  * UID_ARG defines the size of a User ID number when it is passed
  * as a function argument.
@@ -541,7 +627,7 @@ typedef	long long	aligned_offset_t  __attribute__ ((aligned (8)));
 #define	USE_LIB_FIND_CH_INO			1	/* fino.c */
 /* #define	USE_LIB_IS_FILE_NAMED		1	   isfn.c */
 #define	USE_LIB_LKUPDEV				1	/* lkud.c */
-/* #define	USE_LIB_PRINTCHDEVNAME		1	   pdvn.c */
+/* #define	USE_LIB_PRINTDEVNAME		1	   pdvn.c */
 #define	USE_LIB_PROCESS_FILE			1	/* prfp.c */
 #define	USE_LIB_PRINT_TCPTPI			1	/* ptti.c */
 /* #define	USE_LIB_READDEV			1	   rdev.c */
