@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: proc.c,v 1.39 2005/05/11 13:02:46 abe Exp $";
+static char *rcsid = "$Id: proc.c,v 1.42 2007/04/24 16:16:59 abe Exp $";
 #endif
 
 
@@ -165,11 +165,16 @@ alloc_lfile(nm, num)
 	Lf->lts.type = -1;
 	Lf->nlink = 0l;
 
+#if	defined(HASMNTSTAT)
+	Lf->mnt_stat = (unsigned char)0;
+#endif	/* defined(HASMNTSTAT) */
+
 #if	defined(HASSOOPT)
 	Lf->lts.kai = Lf->lts.ltm = 0;
-	Lf->lts.opt = Lf->lts.qlen = Lf->lts.qlim = (unsigned int)0;
+	Lf->lts.opt = Lf->lts.qlen = Lf->lts.qlim = Lf->lts.pqlen
+		    = (unsigned int)0;
 	Lf->lts.rbsz = Lf->lts.sbsz = (unsigned long)0;
-	Lf->lts.qlens = Lf->lts.qlims = Lf->lts.rbszs
+	Lf->lts.qlens = Lf->lts.qlims = Lf->lts.pqlens = Lf->lts.rbszs
 		      = Lf->lts.sbszs = (unsigned char)0;
 #endif	/* defined(HASSOOPT) */
 
@@ -199,7 +204,8 @@ alloc_lfile(nm, num)
 	Lf->is_vxfs = 0;
 #endif	/* defined(HASVXFS) && defined(HASVXFSDNLC) */
 
-	Lf->inode = Lf->off = 0;
+	Lf->inode = (INODETYPE)0;
+	Lf->off = (SZOFFTYPE)0;
 	if (Lp->pss & PS_PRI)
 	    Lf->sf = Lp->sf;
 	else
@@ -318,6 +324,14 @@ alloc_lproc(pid, pgid, ppid, uid, cmd, pss, sf)
  */
 	Lp->zn = (char *)NULL;
 #endif	/* defined(HASZONES) */
+ 
+#if	defined(HASSELINUX)
+/*
+ * Clear the security context pointer.  The dialect's own code will
+ * set it.
+ */
+	Lp->cntx = (char *)NULL;
+#endif	/* defined(HASSELINUX) */
 
 }
 
@@ -421,7 +435,7 @@ ent_inaddr(la, lp, fa, fp, af)
 	    else
 #endif	/* defined(HASIPv6) */
 
-	        Lf->li[0].ia.a4 = *(struct in_addr *)la;
+		Lf->li[0].ia.a4 = *(struct in_addr *)la;
 	    Lf->li[0].p = lp;
 	} else
 	    Lf->li[0].af = 0;
@@ -550,7 +564,6 @@ is_cmd_excl(cmd, pss, sf)
 	short *pss;			/* process state */
 	short *sf;			/* process select flags */
 {
-	char buf[1024];
 	int i;
 	struct str_lst *sp;
 /*
@@ -953,6 +966,11 @@ print_proc()
 	    if (FieldSel[LSOF_FIX_ZONE].st && Fzone && Lp->zn)
 		(void) printf("%c%s%c", LSOF_FID_ZONE, Lp->zn, Terminator);
 #endif	/* defined(HASZONES) */
+ 
+#if	defined(HASSELINUX)
+	    if (FieldSel[LSOF_FIX_CNTX].st && Fcntx && Lp->cntx)
+		(void) printf("%c%s%c", LSOF_FID_CNTX, Lp->cntx, Terminator);
+#endif	/* defined(HASSELINUX) */
 
 	    if (FieldSel[LSOF_FIX_PGID].st && Fpgid)
 		(void) printf("%c%d%c", LSOF_FID_PGID, Lp->pgid, Terminator);
@@ -1112,7 +1130,9 @@ print_proc()
 		lc++;
 	    }
 	    if (FieldSel[LSOF_FIX_INODE].st && Lf->inp_ty == 1) {
-		(void) printf("%c%lu%c", LSOF_FID_INODE, Lf->inode, Terminator);
+		putchar(LSOF_FID_INODE);
+		(void) printf(InodeFmt_d, Lf->inode);
+		putchar(Terminator);
 		lc++;
 	    }
 	    if (FieldSel[LSOF_FIX_NLINK].st && Lf->nlink_def) {
